securitysettings/eapqtdialogs/inc/eapmschapv2oldpwddialog.h
changeset 36 c98682f98478
parent 34 ad1f037f1ac2
--- a/securitysettings/eapqtdialogs/inc/eapmschapv2oldpwddialog.h	Thu Jun 24 11:23:08 2010 +0300
+++ b/securitysettings/eapqtdialogs/inc/eapmschapv2oldpwddialog.h	Fri Jul 09 10:14:51 2010 +0300
@@ -16,18 +16,33 @@
 */
 
 /*
-* %version: 3 %
+* %version: 4 %
 */
 
 #ifndef __EAPMSCHAPV2OLDPWDDIALOG_H__
 #define __EAPMSCHAPV2OLDPWDDIALOG_H__
 
+// System includes
 #include <HbInputDialog>
 #include <hbdevicedialoginterface.h>
 
+// User includes
+
+// Forward declarations
 class HbTranslator;
 class EapQtValidator;
 
+// External data types
+
+// Constants
+
+/*!
+   @addtogroup group_eap_mschapv2_old_pwd_dialog
+   @{
+ */
+
+// Class declaration
+
 class EapMschapv2OldPwdDialog: public HbInputDialog, public HbDeviceDialogInterface
     {
     Q_OBJECT
@@ -44,16 +59,18 @@
         
         /* Device dialog parameters to be set while dialog is displayed.
          * Not supported.
+         * (from HbDeviceDialogInterface)
          */
         bool setDeviceDialogParameters(const QVariantMap &parameters);
         
-        /* Not supported */
+        /* Not supported. (from HbDeviceDialogInterface) */
         int deviceDialogError() const;
         
         /* Closes the device dialog */
         void closeDeviceDialog(bool byClient);
         
-        /* Returns a pointer to this dialog widget */
+        /* Returns a pointer to this dialog widget. 
+           (from HbDeviceDialogInterface) */
         HbPopup *deviceDialogWidget() const;
                 
     signals:
@@ -79,23 +96,26 @@
         
         Q_DISABLE_COPY(EapMschapv2OldPwdDialog)
     
-    private:
-        /* Pointer to the line edit object */
+    private: // data
+        // NOT OWNED
+        //! Pointer to the line edit object
         HbLineEdit *mEdit;
-                
-        /* Pointer to the password validator object */
+        
+        // OWNED             
+        //! Pointer to the password validator object
         QScopedPointer<EapQtValidator> mPwdValidator;
                 
-        /* Pointer to the HbTranslator */
+        //! Pointer to the HbTranslator
         QScopedPointer<HbTranslator> mTranslator;
         
-        /* Tells whether Ok Action has already been pressed */
+        //! Tells whether Ok Action has already been pressed
         bool mOkActionPressed;
         
-        /* Tells whether close has already been called for the dialog */
+        //! Tells whether close has already been called for the dialog
         bool mClose;
     };
 
+/*! @} */
 
 #endif // __EAPMSCHAPV2OLDPWDDIALOG_H__
@@ -44,16 +59,18 @@
         int deviceDialogError() const;
         
-        /* Closes the device dialog */
+        /* Closes the device dialog. (from HbDeviceDialogInterface) */
         void closeDeviceDialog(bool byClient);
         